@@ -1,8 +1,8 @@
 from .drivable import Drivable
 from .driver import Driver
-from .joystick import Joystick
-from .keyboard_control import KeyboardControl
+from .joystick_ import Joystick as joystick
+from .keyboard_control_ import KeyboardControl as keyboard_control
 from .odometer import Odometer, VelocityProvider
 from .path_segment import PathSegment
-from .robot_object import RobotObject
+from .robot_object_ import RobotObject as robot_object
 from .steerer import Steerer
