@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import io
-import urllib.parse
 from dataclasses import dataclass
 from typing import Optional
 
@@ -29,10 +28,6 @@ class Image:
     data: Optional[bytes] = None
     detections: Optional[Detections] = None
 
-    @property
-    def url(self) -> str:
-        return f'camera/{urllib.parse.quote_plus(self.camera_id)}/{self.time}'
-
     @property
     def id(self) -> str:
         return f'{self.camera_id}/{self.time}'
